<?php

namespace App\Controller;

use App\Form\LoginType;
use App\Repository\UserRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Form\FormError;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Notifier\NotifierInterface;
use Symfony\Component\Notifier\Recipient\Recipient;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Security\Http\LoginLink\LoginLinkHandlerInterface;
use Symfony\Component\Security\Http\LoginLink\LoginLinkNotification;

class SecurityController extends AbstractController
{
    #[Route('/login_check', name: 'login_check')]
    public function check(): never
    {
        throw new \LogicException('This code should never be reached');
    }

    #[Route('/login', name: 'login')]
    public function requestLoginLink(
        NotifierInterface $notifier,
        LoginLinkHandlerInterface $loginLinkHandler,
        UserRepository $userRepository,
        Request $request
    ): Response
    {
        $form = $this->createForm(LoginType::class);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $email = $form->get('email')->getData();
            $user = $userRepository->findOneBy(['email' => $email]);
            if ($user) {

                $loginLinkDetails = $loginLinkHandler->createLoginLink($user);
                $loginLink = $loginLinkDetails->getUrl();

                $notification = new LoginLinkNotification(
                    $loginLinkDetails,
                    'Bienvenue sur One Movie One Week' // email subject
                );
                $recipient = new Recipient($user->getEmail());
                $notifier->send($notification, $recipient);

                return $this->redirectToRoute('app_login_sent');
            }
            $form->get('email')->addError(new FormError('Aucun utilisateur avec cet email'));
        }
        // if it's not submitted, render the form to request the "login link"
        return $this->render('security/request_login_link.html.twig', [
            'form' => $form
        ]);
    }

    #[Route('/sent', name: 'app_login_sent')]
    public function loginSent(): Response
    {
        return $this->render('security/login_link_sent.html.twig', [
            'message' => 'Lien de connexion envoyé avec succès.',
        ]);
    }
}
